@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "index": 64,
     "lineNumber": 7,
     "column": 2,
