@@ -1,4 +1,4 @@
-module.exports = {
+export default {
     "message": "Await expression cannot be a default value",
     "column": 8,
     "index": 31,
