@@ -3,14 +3,13 @@
  * @author Kai Cataldo
  */
 
-"use strict";
-
 //------------------------------------------------------------------------------
 // Requirements
 //------------------------------------------------------------------------------
 
-const assert = require("assert"),
-    espree = require("../../espree");
+import assert from "assert";
+import * as espree from "../../espree.js";
+
 
 //------------------------------------------------------------------------------
 // Tests
@@ -18,7 +17,7 @@ const assert = require("assert"),
 
 describe("latestEcmaVersion", () => {
     it("should return the latest supported ecmaVersion", () => {
-        assert.strictEqual(espree.latestEcmaVersion, 12);
+        assert.strictEqual(espree.latestEcmaVersion, 13);
     });
 });
 
@@ -26,7 +25,7 @@ describe("supportedEcmaVersions", () => {
     it("should return an array of all supported versions", () => {
         assert.deepStrictEqual(
             espree.supportedEcmaVersions,
-            [3, 5, 6, 7, 8, 9, 10, 11, 12]
+            [3, 5, 6, 7, 8, 9, 10, 11, 12, 13]
         );
     });
 });
